@@ -314,7 +314,7 @@ add_key(const char *keyring, long valid_after)
  * remove.
  */
 static void
-remove_key(const char *keyring, unsigned long index)
+remove_key(const char *keyring, unsigned long n)
 {
     WEBAUTH_KEYRING *ring;
     int s;
@@ -322,9 +322,9 @@ remove_key(const char *keyring, unsigned long index)
     s = webauth_keyring_read_file(keyring, &ring);
     if (s != WA_ERR_NONE)
         die_webauth(s, "cannot read keyring %s", keyring);
-    s = webauth_keyring_remove(ring, index);
+    s = webauth_keyring_remove(ring, n);
     if (s != WA_ERR_NONE)
-        die_webauth(s, "cannot remove key %lu from keyring", index);
+        die_webauth(s, "cannot remove key %lu from keyring", n);
     s = webauth_keyring_write_file(ring, keyring);
     if (s != WA_ERR_NONE)
         die_webauth(s, "cannot write keyring to %s", keyring);
@@ -372,7 +372,7 @@ int
 main(int argc, char **argv)
 {
     int option;
-    bool verbose;
+    bool verbose = false;
     unsigned long id;
     long offset;
     char *end;
@@ -380,7 +380,13 @@ main(int argc, char **argv)
     const char *command = "list";
 
     message_program_name = argv[0];
-    while ((option = getopt(argc, argv, "f:hv")) != EOF) {
+
+    /*
+     * The + tells GNU getopt to stop option parsing at the first non-argument
+     * rather than proceeding on to find options anywhere.  This allows easier
+     * specification of negative time offsets.
+     */
+    while ((option = getopt(argc, argv, "+f:hv")) != EOF) {
         switch (option) {
         case 'f':
             keyring = optarg;
@@ -391,6 +397,8 @@ main(int argc, char **argv)
         case 'v':
             verbose = true;
             break;
+        case '+':
+            fprintf(stderr, "%s: invalid option -- +\n", argv[0]);
         default:
             usage(1);
             break;
@@ -402,6 +410,7 @@ main(int argc, char **argv)
         usage(1);
     if (argc > 0) {
         command = argv[0];
+        argc--;
         argv++;
     }
 
